#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
#
# VERSION and DEFS_FILE are required for all extensions


class NfvProfile_1_0_0(object):
    VERSION = 'tosca_simple_profile_for_nfv_1_0_0'

    DEFS_FILE = 'TOSCA_nfv_definition_1_0_0.yaml'

    SECTIONS = ('metadata')
